@@ -6,9 +6,11 @@
 # Fastberry
 import fastberry as fb
 
+# Type(s) Tools
+from .. import forms, manager, types
+
+
 # Create your API (GraphQL) here.
-
-
 @fb.gql
 class Demo:
     """Demo Api"""
@@ -17,7 +19,7 @@ class Demo:
         """Meta-Data"""
 
         app = False
-        model = "user"
+        model = None
 
     class Query:
         """Query"""
